/*jshint curly:true, eqeqeq:true, laxbreak:true, noempty:false */
/*

  The MIT License (MIT)

  Copyright (c) 2007-2013 Einar Lielmanis and contributors.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation files
  (the "Software"), to deal in the Software without restriction,
  including without limitation the rights to use, copy, modify, merge,
  publish, distribute, sublicense, and/or sell copies of the Software,
  and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.

 JS Beautifier
---------------


  Written by Einar Lielmanis, <einar@jsbeautifier.org>
      http://jsbeautifier.org/

  Originally converted to javascript by Vital, <vital76@gmail.com>
  "End braces on own line" added by Chris J. Shull, <chrisjshull@gmail.com>
  Parsing improvements for brace-less statements by Liam Newman <bitwiseman@gmail.com>


  Usage:
    js_beautify(js_source_text);
    js_beautify(js_source_text, options);

  The options are:
    indent_size (default 4)          - indentation size,
    indent_char (default space)      - character to indent with,
    preserve_newlines (default true) - whether existing line breaks should be preserved,
    max_preserve_newlines (default unlimited) - maximum number of line breaks to be preserved in one chunk,

    jslint_happy (default false) - if true, then jslint-stricter mode is enforced.

            jslint_happy        !jslint_happy
            ---------------------------------
            function ()         function()

            switch () {         switch() {
            case 1:               case 1:
              break;                break;
            }                   }

    space_after_anon_function (default false) - should the space before an anonymous function's parens be added, "function()" vs "function ()",
          NOTE: This option is overriden by jslint_happy (i.e. if jslint_happy is true, space_after_anon_function is true by design)

    brace_style (default "collapse") - "collapse-preserve-inline" | "collapse" | "expand" | "end-expand" | "none"
            put braces on the same line as control statements (default), or put braces on own line (Allman / ANSI style), or just put end braces on own line, or attempt to keep them where they are.

    space_before_conditional (default true) - should the space before conditional statement be added, "if(true)" vs "if (true)",

    unescape_strings (default false) - should printable characters in strings encoded in \xNN notation be unescaped, "example" vs "\x65\x78\x61\x6d\x70\x6c\x65"

    wrap_line_length (default unlimited) - lines should wrap at next opportunity after this number of characters.
          NOTE: This is not a hard limit. Lines will continue until a point where a newline would
                be preserved if it were present.

    end_with_newline (default false)  - end output with a newline


    e.g

    js_beautify(js_source_text, {
      'indent_size': 1,
      'indent_char': '\t'
    });

*/

// Object.values polyfill found here:
// http://tokenposts.blogspot.com.au/2012/04/javascript-objectkeys-browser.html
if (!Object.values) {
    Object.values = function(o) {
        if (o !== Object(o)) {
            throw new TypeError('Object.values called on a non-object');
        }
        var k = [],
            p;
        for (p in o) {
            if (Object.prototype.hasOwnProperty.call(o, p)) {
                k.push(o[p]);
            }
        }
        return k;
    };
}

(function(){window.js_beautify=function(O,S){function h(b,l){for(var h=0;h<l.length;h+=1)if(l[h]===b)return!0;return!1}function T(b){b=b||A.before_newline;var l=Object.values(A);if(!h(b,l))throw Error("Invalid Option Value: The option 'operator_position' must be one of the following values\n"+l+"\nYou passed in: '"+b+"'");return b}function U(b){var l=0,h=-1,r=[],m=!0;this.set_indent=function(r){l=b.baseIndentLength+r*b.indent_length;h=r};this.get_character_count=function(){return l};this.is_empty=
function(){return m};this.last=function(){return this._empty?null:r[r.length-1]};this.push=function(b){r.push(b);l+=b.length;m=!1};this.pop=function(){var b=null;m||(b=r.pop(),l-=b.length,m=0===r.length);return b};this.remove_indent=function(){0<h&&(--h,l-=b.indent_length)};this.trim=function(){for(;" "===this.last();)r.pop(),--l;m=0===r.length};this.toString=function(){var l="";this._empty||(0<=h&&(l=b.indent_cache[h]),l+=r.join(""));return l}}function V(b,l){l=l||"";this.indent_cache=[l];this.baseIndentLength=
l.length;this.indent_length=b.length;this.raw=!1;var h=[];this.baseIndentString=l;this.indent_string=b;this.current_line=this.previous_line=null;this.space_before_token=!1;this.add_outputline=function(){this.previous_line=this.current_line;this.current_line=new U(this);h.push(this.current_line)};this.add_outputline();this.get_line_number=function(){return h.length};this.add_new_line=function(b){return 1===this.get_line_number()&&this.just_added_newline()?!1:b||!this.just_added_newline()?(this.raw||
this.add_outputline(),!0):!1};this.get_code=function(){return h.join("\n").replace(/[\r\n\t ]+$/,"")};this.set_indent=function(b){if(1<h.length){for(;b>=this.indent_cache.length;)this.indent_cache.push(this.indent_cache[this.indent_cache.length-1]+this.indent_string);this.current_line.set_indent(b);return!0}this.current_line.set_indent(0);return!1};this.add_raw_token=function(b){for(var h=0;h<b.newlines;h++)this.add_outputline();this.current_line.push(b.whitespace_before);this.current_line.push(b.text);
this.space_before_token=!1};this.add_token=function(b){this.add_space_before_token();this.current_line.push(b)};this.add_space_before_token=function(){this.space_before_token&&!this.just_added_newline()&&this.current_line.push(" ");this.space_before_token=!1};this.remove_redundant_indentation=function(b){if(!b.multiline_frame&&b.mode!==m.ForInitializer&&b.mode!==m.Conditional){b=b.start_line_index;for(var l=h.length;b<l;)h[b].remove_indent(),b++}};this.trim=function(m){m=void 0===m?!1:m;for(this.current_line.trim(b,
l);m&&1<h.length&&this.current_line.is_empty();)h.pop(),this.current_line=h[h.length-1],this.current_line.trim();this.previous_line=1<h.length?h[h.length-2]:null};this.just_added_newline=function(){return this.current_line.is_empty()};this.just_added_blankline=function(){return this.just_added_newline()?1===h.length?!0:h[h.length-2].is_empty():!1}}function W(b,l){function m(a){if(!a.match(C))return null;var b={};I.lastIndex=0;for(var c=I.exec(a);c;)b[c[1]]=c[2],c=I.exec(a);return b}function r(){var a,
n=[];F=0;w="";if(c>=u)return["","TK_EOF"];var p;p=f.length?f[f.length-1]:new J("TK_START_BLOCK","{");var d=b.charAt(c);for(c+=1;h(d,q);){if(x.newline.test(d)){if("\n"!==d||"\r"!==b.charAt(c-2))F+=1,n=[]}else n.push(d);if(c>=u)return["","TK_EOF"];d=b.charAt(c);c+=1}n.length&&(w=n.join(""));if(A.test(d)||"."===d&&A.test(b.charAt(c))){var n=p=!0,r=A;"0"===d&&c<u&&/[XxOoBb]/.test(b.charAt(c))?(n=p=!1,r=/[Bb]/.test(b.charAt(c))?t:/[Oo]/.test(b.charAt(c))?B:G,d+=b.charAt(c),c+=1):"."===d?p=!1:(d="",--c);
for(;c<u&&r.test(b.charAt(c));)d+=b.charAt(c),c+=1,p&&c<u&&"."===b.charAt(c)?(d+=b.charAt(c),c+=1,p=!1):n&&c<u&&/[Ee]/.test(b.charAt(c))&&(d+=b.charAt(c),c+=1,c<u&&/[+-]/.test(b.charAt(c))&&(d+=b.charAt(c),c+=1),p=n=!1);return[d,"TK_WORD"]}if(x.isIdentifierStart(b.charCodeAt(c-1))){if(c<u)for(;x.isIdentifierChar(b.charCodeAt(c))&&(d+=b.charAt(c),c+=1,c!==u););return"TK_DOT"===p.type||"TK_RESERVED"===p.type&&h(p.text,["set","get"])||!h(d,K)?[d,"TK_WORD"]:"in"===d?[d,"TK_OPERATOR"]:[d,"TK_RESERVED"]}if("("===
d||"["===d)return[d,"TK_START_EXPR"];if(")"===d||"]"===d)return[d,"TK_END_EXPR"];if("{"===d)return[d,"TK_START_BLOCK"];if("}"===d)return[d,"TK_END_BLOCK"];if(";"===d)return[d,"TK_SEMICOLON"];if("/"===d){n="";if("*"===b.charAt(c))return c+=1,D.lastIndex=c,d=D.exec(b),n="/*"+d[0],c+=d[0].length,(p=m(n))&&"start"===p.ignore&&(k.lastIndex=c,d=k.exec(b),n+=d[0],c+=d[0].length),n=n.replace(x.allLineBreaks,"\n"),[n,"TK_BLOCK_COMMENT",p];if("/"===b.charAt(c))return c+=1,H.lastIndex=c,d=H.exec(b),n="//"+d[0],
c+=d[0].length,[n,"TK_COMMENT"]}n=/^<([-a-zA-Z:0-9_.]+|{.+?}|!\[CDATA\[[\s\S]*?\]\])(\s+{.+?}|\s+[-a-zA-Z:0-9_.]+|\s+[-a-zA-Z:0-9_.]+\s*=\s*('[^']*'|"[^"]*"|{.+?}))*\s*(\/?)\s*>/;if("`"===d||"'"===d||'"'===d||("/"===d||l.e4x&&"<"===d&&b.slice(c-1).match(n))&&("TK_RESERVED"===p.type&&h(p.text,"return case throw else do typeof yield".split(" "))||"TK_END_EXPR"===p.type&&")"===p.text&&p.parent&&"TK_RESERVED"===p.parent.type&&h(p.parent.text,["if","while","for"])||h(p.type,"TK_COMMENT TK_START_EXPR TK_START_BLOCK TK_END_BLOCK TK_OPERATOR TK_EQUALS TK_EOF TK_SEMICOLON TK_COMMA".split(" ")))){var r=
d,g=!1,M=!1;a=d;if("/"===r)for(d=!1;c<u&&(g||d||b.charAt(c)!==r)&&!x.newline.test(b.charAt(c));)a+=b.charAt(c),g?g=!1:(g="\\"===b.charAt(c),"["===b.charAt(c)?d=!0:"]"===b.charAt(c)&&(d=!1)),c+=1;else if(l.e4x&&"<"===r){if(p=/<(\/?)([-a-zA-Z:0-9_.]+|{.+?}|!\[CDATA\[[\s\S]*?\]\])(\s+{.+?}|\s+[-a-zA-Z:0-9_.]+|\s+[-a-zA-Z:0-9_.]+\s*=\s*('[^']*'|"[^"]*"|{.+?}))*\s*(\/?)\s*>/g,d=b.slice(c-1),(n=p.exec(d))&&0===n.index){for(var r=n[2],E=0;n;){var C=!!n[1],y=n[2],X=!!n[n.length-1]||"![CDATA["===y.slice(0,
8);y!==r||X||(C?--E:++E);if(0>=E)break;n=p.exec(d)}p=n?n.index+n[0].length:d.length;d=d.slice(0,p);c+=p-1;d=d.replace(x.allLineBreaks,"\n");return[d,"TK_STRING"]}}else{var N=function(d,e,f){for(var y;c<u;){y=b.charAt(c);if(!g&&(y===d||!e&&x.newline.test(y)))break;(g||e)&&x.newline.test(y)?("\r"===y&&"\n"===b.charAt(c+1)&&(c+=1,y=b.charAt(c)),a+="\n"):a+=y;if(g){if("x"===y||"u"===y)M=!0;g=!1}else g="\\"===y;c+=1;f&&-1!==a.indexOf(f,a.length-f.length)&&("`"===d?N("}",e,"`"):N("`",e,"${"))}};"`"===r?
N("`",!0,"${"):N(r)}M&&l.unescape_strings&&(a=v(a));if(c<u&&b.charAt(c)===r&&(a+=r,c+=1,"/"===r))for(;c<u&&x.isIdentifierStart(b.charCodeAt(c));)a+=b.charAt(c),c+=1;return[a,"TK_STRING"]}if("#"===d){if(0===f.length&&"!"===b.charAt(c)){for(a=d;c<u&&"\n"!==d;)d=b.charAt(c),a+=d,c+=1;return[a.replace(/^\s+|\s+$/g,"")+"\n","TK_UNKNOWN"]}p="#";if(c<u&&A.test(b.charAt(c))){do d=b.charAt(c),p+=d,c+=1;while(c<u&&"#"!==d&&"="!==d);"#"!==d&&("["===b.charAt(c)&&"]"===b.charAt(c+1)?(p+="[]",c+=2):"{"===b.charAt(c)&&
"}"===b.charAt(c+1)&&(p+="{}",c+=2));return[p,"TK_WORD"]}}if("<"===d&&("?"===b.charAt(c)||"%"===b.charAt(c))&&(L.lastIndex=c-1,p=L.exec(b)))return d=p[0],c+=d.length-1,d=d.replace(x.allLineBreaks,"\n"),[d,"TK_STRING"];if("<"===d&&"\x3c!--"===b.substring(c-1,c+3)){c+=3;for(d="\x3c!--";!x.newline.test(b.charAt(c))&&c<u;)d+=b.charAt(c),c++;e=!0;return[d,"TK_COMMENT"]}if("-"===d&&e&&"--\x3e"===b.substring(c-1,c+2))return e=!1,c+=2,["--\x3e","TK_COMMENT"];if("."===d)return[d,"TK_DOT"];if(h(d,z)){for(;c<
u&&h(d+b.charAt(c),z)&&!(d+=b.charAt(c),c+=1,c>=u););return","===d?[d,"TK_COMMA"]:"="===d?[d,"TK_EQUALS"]:[d,"TK_OPERATOR"]}return[d,"TK_UNKNOWN"]}function v(a){for(var b=!1,c="",d=0,e,g,f;b||d<a.length;)if(f=a.charAt(d),d++,b){b=!1;if("x"===f)e=a.substr(d,2),d+=2;else if("u"===f)e=a.substr(d,4),d+=4;else{c+="\\"+f;continue}if(!e.match(/^[0123456789abcdefABCDEF]+$/))return a;g=parseInt(e,16);if(0<=g&&32>g)c="x"===f?c+("\\x"+e):c+("\\u"+e);else if(34===g||39===g||92===g)c+="\\"+String.fromCharCode(g);
else{if("x"===f&&126<g&&255>=g)return a;c+=String.fromCharCode(g)}}else"\\"===f?b=!0:c+=f;return c}var q=["\n","\r","\t"," "],A=/[0-9]/,t=/[01]/,B=/[01234567]/,G=/[0123456789abcdefABCDEF]/;this.positionable_operators="!= !== % & && * ** + - / : < << <= == === > >= >> >>> ? ^ | ||".split(" ");var z=this.positionable_operators.concat("! %= &= *= **= ++ += , -- -= /= :: <<= = => >>= >>>= ^= |= ~".split(" "));this.line_starters="continue try throw return var let const if switch case default for while break function import export".split(" ");
var K=this.line_starters.concat("do in else get set new catch finally typeof yield async await from as".split(" ")),D=/([\s\S]*?)((?:\*\/)|$)/g,H=/([^\n\r\u2028\u2029]*)/g,C=/\/\* beautify( \w+[:]\w+)+ \*\//g,I=/ (\w+)[:](\w+)/g,k=/([\s\S]*?)((?:\/\*\sbeautify\signore:end\s\*\/)|$)/g,L=/((<\?php|<\?=)[\s\S]*?\?>)|(<%[\s\S]*?%>)/g,F,w,e,f,c,u;this.tokenize=function(){u=b.length;c=0;e=!1;f=[];for(var a,k,h,d=null,l=[],g=[];!k||"TK_EOF"!==k.type;){h=r();for(a=new J(h[1],h[0],F,w);"TK_COMMENT"===a.type||
"TK_BLOCK_COMMENT"===a.type||"TK_UNKNOWN"===a.type;)"TK_BLOCK_COMMENT"===a.type&&(a.directives=h[2]),g.push(a),h=r(),a=new J(h[1],h[0],F,w);g.length&&(a.comments_before=g,g=[]);"TK_START_BLOCK"===a.type||"TK_START_EXPR"===a.type?(a.parent=k,l.push(d),d=a):("TK_END_BLOCK"===a.type||"TK_END_EXPR"===a.type)&&d&&("]"===a.text&&"["===d.text||")"===a.text&&"("===d.text||"}"===a.text&&"{"===d.text)&&(a.parent=d.parent,a.opened=d,d=l.pop());f.push(a);k=a}return f}}var x={};(function(b){var h=RegExp("[\u00aa\u00b5\u00ba\u00c0-\u00d6\u00d8-\u00f6\u00f8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05d0-\u05ea\u05f0-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u08a0\u08a2-\u08ac\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097f\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c33\u0c35-\u0c39\u0c3d\u0c58\u0c59\u0c60\u0c61\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d05-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d60\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e87\u0e88\u0e8a\u0e8d\u0e94-\u0e97\u0e99-\u0e9f\u0ea1-\u0ea3\u0ea5\u0ea7\u0eaa\u0eab\u0ead-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f4\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f0\u1700-\u170c\u170e-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1877\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191c\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19c1-\u19c7\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4b\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1ce9-\u1cec\u1cee-\u1cf1\u1cf5\u1cf6\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2119-\u211d\u2124\u2126\u2128\u212a-\u212d\u212f-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2c2e\u2c30-\u2c5e\u2c60-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u2e2f\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309d-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312d\u3131-\u318e\u31a0-\u31ba\u31f0-\u31ff\u3400-\u4db5\u4e00-\u9fcc\ua000-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua697\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua78e\ua790-\ua793\ua7a0-\ua7aa\ua7f8-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa80-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uabc0-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc]"),
m=RegExp("[\u00aa\u00b5\u00ba\u00c0-\u00d6\u00d8-\u00f6\u00f8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05d0-\u05ea\u05f0-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u08a0\u08a2-\u08ac\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097f\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c33\u0c35-\u0c39\u0c3d\u0c58\u0c59\u0c60\u0c61\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d05-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d60\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e87\u0e88\u0e8a\u0e8d\u0e94-\u0e97\u0e99-\u0e9f\u0ea1-\u0ea3\u0ea5\u0ea7\u0eaa\u0eab\u0ead-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f4\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f0\u1700-\u170c\u170e-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1877\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191c\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19c1-\u19c7\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4b\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1ce9-\u1cec\u1cee-\u1cf1\u1cf5\u1cf6\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2119-\u211d\u2124\u2126\u2128\u212a-\u212d\u212f-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2c2e\u2c30-\u2c5e\u2c60-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u2e2f\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309d-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312d\u3131-\u318e\u31a0-\u31ba\u31f0-\u31ff\u3400-\u4db5\u4e00-\u9fcc\ua000-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua697\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua78e\ua790-\ua793\ua7a0-\ua7aa\ua7f8-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa80-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uabc0-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc\u0300-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u0620-\u0649\u0672-\u06d3\u06e7-\u06e8\u06fb-\u06fc\u0730-\u074a\u0800-\u0814\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0840-\u0857\u08e4-\u08fe\u0900-\u0903\u093a-\u093c\u093e-\u094f\u0951-\u0957\u0962-\u0963\u0966-\u096f\u0981-\u0983\u09bc\u09be-\u09c4\u09c7\u09c8\u09d7\u09df-\u09e0\u0a01-\u0a03\u0a3c\u0a3e-\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a66-\u0a71\u0a75\u0a81-\u0a83\u0abc\u0abe-\u0ac5\u0ac7-\u0ac9\u0acb-\u0acd\u0ae2-\u0ae3\u0ae6-\u0aef\u0b01-\u0b03\u0b3c\u0b3e-\u0b44\u0b47\u0b48\u0b4b-\u0b4d\u0b56\u0b57\u0b5f-\u0b60\u0b66-\u0b6f\u0b82\u0bbe-\u0bc2\u0bc6-\u0bc8\u0bca-\u0bcd\u0bd7\u0be6-\u0bef\u0c01-\u0c03\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62-\u0c63\u0c66-\u0c6f\u0c82\u0c83\u0cbc\u0cbe-\u0cc4\u0cc6-\u0cc8\u0cca-\u0ccd\u0cd5\u0cd6\u0ce2-\u0ce3\u0ce6-\u0cef\u0d02\u0d03\u0d46-\u0d48\u0d57\u0d62-\u0d63\u0d66-\u0d6f\u0d82\u0d83\u0dca\u0dcf-\u0dd4\u0dd6\u0dd8-\u0ddf\u0df2\u0df3\u0e34-\u0e3a\u0e40-\u0e45\u0e50-\u0e59\u0eb4-\u0eb9\u0ec8-\u0ecd\u0ed0-\u0ed9\u0f18\u0f19\u0f20-\u0f29\u0f35\u0f37\u0f39\u0f41-\u0f47\u0f71-\u0f84\u0f86-\u0f87\u0f8d-\u0f97\u0f99-\u0fbc\u0fc6\u1000-\u1029\u1040-\u1049\u1067-\u106d\u1071-\u1074\u1082-\u108d\u108f-\u109d\u135d-\u135f\u170e-\u1710\u1720-\u1730\u1740-\u1750\u1772\u1773\u1780-\u17b2\u17dd\u17e0-\u17e9\u180b-\u180d\u1810-\u1819\u1920-\u192b\u1930-\u193b\u1951-\u196d\u19b0-\u19c0\u19c8-\u19c9\u19d0-\u19d9\u1a00-\u1a15\u1a20-\u1a53\u1a60-\u1a7c\u1a7f-\u1a89\u1a90-\u1a99\u1b46-\u1b4b\u1b50-\u1b59\u1b6b-\u1b73\u1bb0-\u1bb9\u1be6-\u1bf3\u1c00-\u1c22\u1c40-\u1c49\u1c5b-\u1c7d\u1cd0-\u1cd2\u1d00-\u1dbe\u1e01-\u1f15\u200c\u200d\u203f\u2040\u2054\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2d81-\u2d96\u2de0-\u2dff\u3021-\u3028\u3099\u309a\ua640-\ua66d\ua674-\ua67d\ua69f\ua6f0-\ua6f1\ua7f8-\ua800\ua806\ua80b\ua823-\ua827\ua880-\ua881\ua8b4-\ua8c4\ua8d0-\ua8d9\ua8f3-\ua8f7\ua900-\ua909\ua926-\ua92d\ua930-\ua945\ua980-\ua983\ua9b3-\ua9c0\uaa00-\uaa27\uaa40-\uaa41\uaa4c-\uaa4d\uaa50-\uaa59\uaa7b\uaae0-\uaae9\uaaf2-\uaaf3\uabc0-\uabe1\uabec\uabed\uabf0-\uabf9\ufb20-\ufb28\ufe00-\ufe0f\ufe20-\ufe26\ufe33\ufe34\ufe4d-\ufe4f\uff10-\uff19\uff3f]");
b.newline=/[\n\r\u2028\u2029]/;b.lineBreak=new RegExp("\r\n|"+b.newline.source);b.allLineBreaks=new RegExp(b.lineBreak.source,"g");b.isIdentifierStart=function(b){return 65>b?36===b||64===b:91>b?!0:97>b?95===b:123>b?!0:170<=b&&h.test(String.fromCharCode(b))};b.isIdentifierChar=function(b){return 48>b?36===b:58>b?!0:65>b?!1:91>b?!0:97>b?95===b:123>b?!0:170<=b&&m.test(String.fromCharCode(b))}})(x);var A={before_newline:"before-newline",after_newline:"after-newline",preserve_newline:"preserve-newline"},
R=[A.before_newline,A.preserve_newline],m={BlockStatement:"BlockStatement",Statement:"Statement",ObjectLiteral:"ObjectLiteral",ArrayLiteral:"ArrayLiteral",ForInitializer:"ForInitializer",Conditional:"Conditional",Expression:"Expression"},J=function(b,h,m,r,v){this.type=b;this.text=h;this.comments_before=[];this.newlines=m||0;this.wanted_newline=0<m;this.whitespace_before=r||"";this.parent=v||null;this.directives=this.opened=null};return(new function(b,l){function J(a,b){var c=0;a&&(c=a.indentation_level,
!k.just_added_newline()&&a.line_indent_level>c&&(c=a.line_indent_level));return{mode:b,parent:a,last_text:a?a.last_text:"",last_word:a?a.last_word:"",declaration_statement:!1,declaration_assignment:!1,multiline_frame:!1,inline_frame:!1,if_block:!1,else_block:!1,do_block:!1,do_while:!1,import_block:!1,in_case_statement:!1,in_case:!1,case_body:!1,indentation_level:c,line_indent_level:a?a.line_indent_level:c,start_line_index:k.get_line_number(),ternary_depth:0}}function r(b){var c=b.newlines;if(g.keep_array_indentation&&
a.mode===m.ArrayLiteral)for(var d=0;d<c;d+=1)q(0<d);else if(g.max_preserve_newlines&&c>g.max_preserve_newlines&&(c=g.max_preserve_newlines),g.preserve_newlines&&1<b.newlines)for(q(),d=1;d<c;d+=1)q(!0);e=b;Q[e.type]()}function v(b){b=void 0===b?!1:b;if(!k.just_added_newline()){b=g.preserve_newlines&&e.wanted_newline||b;if(h(a.last_text,w.positionable_operators)||h(e.text,w.positionable_operators)){var c=h(a.last_text,w.positionable_operators)&&h(g.operator_position,R)||h(e.text,w.positionable_operators);
b=b&&c}b?q(!1,!0):!g.wrap_line_length||"TK_RESERVED"===f&&h(a.last_text,O)||k.current_line.get_character_count()+e.text.length+(k.space_before_token?1:0)>=g.wrap_line_length&&q(!1,!0)}}function q(b,c){if(!c&&";"!==a.last_text&&","!==a.last_text&&"="!==a.last_text&&"TK_OPERATOR"!==f)for(;a.mode===m.Statement&&!a.if_block&&!a.do_block;)z();k.add_new_line(b)&&(a.multiline_frame=!0)}function P(){k.just_added_newline()&&(g.keep_array_indentation&&a.mode===m.ArrayLiteral&&e.wanted_newline?(k.current_line.push(e.whitespace_before),
k.space_before_token=!1):k.set_indent(a.indentation_level)&&(a.line_indent_level=a.indentation_level))}function t(a){if(k.raw)k.add_raw_token(e);else{if(g.comma_first&&"TK_COMMA"===f&&k.just_added_newline()&&","===k.previous_line.last()){var b=k.previous_line.pop();k.previous_line.is_empty()&&(k.previous_line.push(b),k.trim(!0),k.current_line.pop(),k.trim());P();k.add_token(",");k.space_before_token=!0}a=a||e.text;P();k.add_token(a)}}function B(b){a?(p.push(a),n=a):n=J(null,b);a=J(n,b)}function G(a){return h(a,
[m.Expression,m.ForInitializer,m.Conditional])}function z(){0<p.length&&(n=a,a=p.pop(),n.mode===m.Statement&&k.remove_redundant_indentation(n))}function K(){return a.parent.mode===m.ObjectLiteral&&a.mode===m.Statement&&(":"===a.last_text&&0===a.ternary_depth||"TK_RESERVED"===f&&h(a.last_text,["get","set"]))}function D(){return"TK_RESERVED"===f&&h(a.last_text,["var","let","const"])&&"TK_WORD"===e.type||"TK_RESERVED"===f&&"do"===a.last_text||"TK_RESERVED"===f&&h(a.last_text,["return","throw"])&&!e.wanted_newline||
"TK_RESERVED"===f&&"else"===a.last_text&&("TK_RESERVED"!==e.type||"if"!==e.text)||"TK_END_EXPR"===f&&(n.mode===m.ForInitializer||n.mode===m.Conditional)||"TK_WORD"===f&&a.mode===m.BlockStatement&&!a.in_case&&"--"!==e.text&&"++"!==e.text&&"function"!==c&&"TK_WORD"!==e.type&&"TK_RESERVED"!==e.type||a.mode===m.ObjectLiteral&&(":"===a.last_text&&0===a.ternary_depth||"TK_RESERVED"===f&&h(a.last_text,["get","set"]))?(B(m.Statement),a.indentation_level+=1,"TK_RESERVED"===f&&h(a.last_text,["var","let","const"])&&
"TK_WORD"===e.type&&(a.declaration_statement=!0),K()||v("TK_RESERVED"===e.type&&h(e.text,["do","for","if","while"])),!0):!1}function H(a){return h(a,"case return do if throw else".split(" "))}function C(a){a=F+(a||0);return 0>a||a>=L.length?null:L[a]}function I(){"TK_RESERVED"===e.type&&(h(e.text,["set","get"])&&a.mode!==m.ObjectLiteral?e.type="TK_WORD":h(e.text,["as","from"])&&!a.import_block?e.type="TK_WORD":a.mode===m.ObjectLiteral&&":"===C(1).text&&(e.type="TK_WORD"));D()||!e.wanted_newline||
G(a.mode)||"TK_OPERATOR"===f&&"--"!==a.last_text&&"++"!==a.last_text||"TK_EQUALS"===f||!g.preserve_newlines&&"TK_RESERVED"===f&&h(a.last_text,["var","let","const","set","get"])||q();if(a.do_block&&!a.do_while){if("TK_RESERVED"===e.type&&"while"===e.text){k.space_before_token=!0;t();k.space_before_token=!0;a.do_while=!0;return}q();a.do_block=!1}if(a.if_block)if(a.else_block||"TK_RESERVED"!==e.type||"else"!==e.text){for(;a.mode===m.Statement;)z();a.if_block=!1;a.else_block=!1}else a.else_block=!0;if("TK_RESERVED"===
e.type&&("case"===e.text||"default"===e.text&&a.in_case_statement)){q();if(a.case_body||g.jslint_happy)0<a.indentation_level&&(!a.parent||a.indentation_level>a.parent.indentation_level)&&--a.indentation_level,a.case_body=!1;t();a.in_case=!0;a.in_case_statement=!0}else{"TK_RESERVED"===e.type&&"function"===e.text&&(!(h(a.last_text,["}",";"])||k.just_added_newline()&&!h(a.last_text,["[","{",":","=",","]))||k.just_added_blankline()||e.comments_before.length||(q(),q(!0)),"TK_RESERVED"===f||"TK_WORD"===
f?"TK_RESERVED"===f&&h(a.last_text,"get set new return export async".split(" "))?k.space_before_token=!0:"TK_RESERVED"===f&&"default"===a.last_text&&"export"===c?k.space_before_token=!0:q():"TK_OPERATOR"===f||"="===a.last_text?k.space_before_token=!0:(a.multiline_frame||!G(a.mode)&&a.mode!==m.ArrayLiteral)&&q());if("TK_COMMA"===f||"TK_START_EXPR"===f||"TK_EQUALS"===f||"TK_OPERATOR"===f)K()||v();"TK_RESERVED"===e.type&&h(e.text,["function","get","set"])?(t(),a.last_word=e.text):(d="NONE","TK_END_BLOCK"===
f?"TK_RESERVED"===e.type&&h(e.text,["else","catch","finally","from"])?"expand"===g.brace_style||"end-expand"===g.brace_style||"none"===g.brace_style&&e.wanted_newline?d="NEWLINE":(d="SPACE",k.space_before_token=!0):d="NEWLINE":"TK_SEMICOLON"===f&&a.mode===m.BlockStatement?d="NEWLINE":"TK_SEMICOLON"===f&&G(a.mode)?d="SPACE":"TK_STRING"===f?d="NEWLINE":"TK_RESERVED"===f||"TK_WORD"===f||"*"===a.last_text&&"function"===c?d="SPACE":"TK_START_BLOCK"===f?d=a.inline_frame?"SPACE":"NEWLINE":"TK_END_EXPR"===
f&&(k.space_before_token=!0,d="NEWLINE"),"TK_RESERVED"===e.type&&h(e.text,w.line_starters)&&")"!==a.last_text&&(d="else"===a.last_text||"export"===a.last_text?"SPACE":"NEWLINE"),"TK_RESERVED"===e.type&&h(e.text,["else","catch","finally"])?"TK_END_BLOCK"!==f||n.mode!==m.BlockStatement||"expand"===g.brace_style||"end-expand"===g.brace_style||"none"===g.brace_style&&e.wanted_newline?q():(k.trim(!0),"}"!==k.current_line.last()&&q(),k.space_before_token=!0):"NEWLINE"===d?"TK_RESERVED"===f&&H(a.last_text)?
k.space_before_token=!0:"TK_END_EXPR"!==f?"TK_START_EXPR"===f&&"TK_RESERVED"===e.type&&h(e.text,["var","let","const"])||":"===a.last_text||("TK_RESERVED"===e.type&&"if"===e.text&&"else"===a.last_text?k.space_before_token=!0:q()):"TK_RESERVED"===e.type&&h(e.text,w.line_starters)&&")"!==a.last_text&&q():a.multiline_frame&&a.mode===m.ArrayLiteral&&","===a.last_text&&"}"===c?q():"SPACE"===d&&(k.space_before_token=!0),t(),a.last_word=e.text,"TK_RESERVED"===e.type&&("do"===e.text?a.do_block=!0:"if"===e.text?
a.if_block=!0:"import"===e.text?a.import_block=!0:a.import_block&&"TK_RESERVED"===e.type&&"from"===e.text&&(a.import_block=!1)))}}var k,L=[],F,w,e,f,c,u,a,n,p,d,Q,g,M="";Q={TK_START_EXPR:function(){D();var b=m.Expression;if("["===e.text){if("TK_WORD"===f||")"===a.last_text){"TK_RESERVED"===f&&h(a.last_text,w.line_starters)&&(k.space_before_token=!0);B(b);t();a.indentation_level+=1;g.space_in_paren&&(k.space_before_token=!0);return}b=m.ArrayLiteral;a.mode!==m.ArrayLiteral||"["!==a.last_text&&(","!==
a.last_text||"]"!==c&&"}"!==c)||g.keep_array_indentation||q()}else"TK_RESERVED"===f&&"for"===a.last_text?b=m.ForInitializer:"TK_RESERVED"===f&&h(a.last_text,["if","while"])&&(b=m.Conditional);";"===a.last_text||"TK_START_BLOCK"===f?q():"TK_END_EXPR"===f||"TK_START_EXPR"===f||"TK_END_BLOCK"===f||"."===a.last_text?v(e.wanted_newline):"TK_RESERVED"===f&&"("===e.text||"TK_WORD"===f||"TK_OPERATOR"===f?"TK_RESERVED"===f&&("function"===a.last_word||"typeof"===a.last_word)||"*"===a.last_text&&"function"===
c?g.space_after_anon_function&&(k.space_before_token=!0):"TK_RESERVED"===f&&(h(a.last_text,w.line_starters)||"catch"===a.last_text)&&g.space_before_conditional&&(k.space_before_token=!0):k.space_before_token=!0;"("===e.text&&"TK_RESERVED"===f&&"await"===a.last_word&&(k.space_before_token=!0);"("!==e.text||"TK_EQUALS"!==f&&"TK_OPERATOR"!==f||K()||v();"("===e.text&&"TK_WORD"!==f&&"TK_RESERVED"!==f&&v();B(b);t();g.space_in_paren&&(k.space_before_token=!0);a.indentation_level+=1},TK_END_EXPR:function(){for(;a.mode===
m.Statement;)z();a.multiline_frame&&v("]"===e.text&&a.mode===m.ArrayLiteral&&!g.keep_array_indentation);g.space_in_paren&&("TK_START_EXPR"!==f||g.space_in_empty_paren?k.space_before_token=!0:(k.trim(),k.space_before_token=!1));"]"===e.text&&g.keep_array_indentation?(t(),z()):(z(),t());k.remove_redundant_indentation(n);a.do_while&&n.mode===m.Conditional&&(n.mode=m.Expression,a.do_block=!1,a.do_while=!1)},TK_START_BLOCK:function(){var b=C(1),d=C(2);d&&(h(d.text,[":",","])&&h(b.type,["TK_STRING","TK_WORD",
"TK_RESERVED"])||h(b.text,["get","set"])&&h(d.type,["TK_WORD","TK_RESERVED"]))?h(c,["class","interface"])?B(m.BlockStatement):B(m.ObjectLiteral):"TK_OPERATOR"===f&&"=>"===a.last_text?B(m.BlockStatement):h(f,["TK_EQUALS","TK_START_EXPR","TK_COMMA","TK_OPERATOR"])||"TK_RESERVED"===f&&h(a.last_text,["return","throw","import"])?B(m.ObjectLiteral):B(m.BlockStatement);b=!b.comments_before.length&&"}"===b.text&&"function"===a.last_word&&"TK_END_EXPR"===f;if("expand"===g.brace_style||"none"===g.brace_style&&
e.wanted_newline)"TK_OPERATOR"!==f&&(b||"TK_EQUALS"===f||"TK_RESERVED"===f&&H(a.last_text)&&"else"!==a.last_text)?k.space_before_token=!0:q(!1,!0);else{if("collapse-preserve-inline"===g.brace_style){b=0;a.inline_frame=!0;do if(b+=1,d=C(b),d.wanted_newline){a.inline_frame=!1;break}while("TK_EOF"!==d.type&&("TK_END_BLOCK"!==d.type||d.opened!==e))}if(n.mode!==m.ArrayLiteral||"TK_START_EXPR"!==f&&"TK_COMMA"!==f)"TK_OPERATOR"!==f&&"TK_START_EXPR"!==f&&("TK_START_BLOCK"===f?q():k.space_before_token=!0);
else{if("TK_COMMA"===f||g.space_in_paren)k.space_before_token=!0;"collapse-preserve-inline"===g.brace_style&&("TK_COMMA"===f||"TK_START_EXPR"===f&&a.inline_frame)&&(v(),n.multiline_frame=n.multiline_frame||a.multiline_frame,a.multiline_frame=!1)}}t();a.indentation_level+=1},TK_END_BLOCK:function(){for(;a.mode===m.Statement;)z();var b="TK_START_BLOCK"===f;"expand"===g.brace_style?b||q():b||(a.inline_frame?k.space_before_token=!0:a.mode===m.ArrayLiteral&&g.keep_array_indentation?(g.keep_array_indentation=
!1,q(),g.keep_array_indentation=!0):q());z();t()},TK_WORD:I,TK_RESERVED:I,TK_SEMICOLON:function(){D()&&(k.space_before_token=!1);for(;a.mode===m.Statement&&!a.if_block&&!a.do_block;)z();a.import_block&&(a.import_block=!1);t()},TK_STRING:function(){D()?k.space_before_token=!0:"TK_RESERVED"===f||"TK_WORD"===f||a.inline_frame?k.space_before_token=!0:"TK_COMMA"===f||"TK_START_EXPR"===f||"TK_EQUALS"===f||"TK_OPERATOR"===f?K()||v():q();t()},TK_EQUALS:function(){D();a.declaration_statement&&(a.declaration_assignment=
!0);k.space_before_token=!0;t();k.space_before_token=!0},TK_OPERATOR:function(){D();if("TK_RESERVED"===f&&H(a.last_text))k.space_before_token=!0,t();else if("*"===e.text&&"TK_DOT"===f)t();else if("::"===e.text)t();else if("TK_OPERATOR"===f&&h(g.operator_position,R)&&v(),":"===e.text&&a.in_case)a.case_body=!0,a.indentation_level+=1,t(),q(),a.in_case=!1;else{var b=!0,d=!0,c=!1,l="*"===e.text&&"TK_RESERVED"===f&&"function"===a.last_text,n=h(e.text,["-","+"])&&(h(f,["TK_START_BLOCK","TK_START_EXPR","TK_EQUALS",
"TK_OPERATOR"])||h(a.last_text,w.line_starters)||","===a.last_text);":"===e.text?0===a.ternary_depth?b=!1:(--a.ternary_depth,c=!0):"?"===e.text&&(a.ternary_depth+=1);if(!n&&!l&&g.preserve_newlines&&h(e.text,w.positionable_operators)){var p=":"===e.text,r=p&&c,c=p&&!c;switch(g.operator_position){case A.before_newline:k.space_before_token=!c;t();p&&!r||v();k.space_before_token=!0;return;case A.after_newline:k.space_before_token=!0;!p||r?C(1).wanted_newline?q(!1,!0):v():k.space_before_token=!1;t();k.space_before_token=
!0;return;case A.preserve_newline:c||v();b=!(k.just_added_newline()||c);k.space_before_token=b;t();k.space_before_token=!0;return}}h(e.text,["--","++","!","~"])||n?(d=b=!1,!e.wanted_newline||"--"!==e.text&&"++"!==e.text||q(!1,!0),";"===a.last_text&&G(a.mode)&&(b=!0),"TK_RESERVED"===f?b=!0:"TK_END_EXPR"===f?b=!("]"===a.last_text&&("--"===e.text||"++"===e.text)):"TK_OPERATOR"===f&&(b=h(e.text,["--","-","++","+"])&&h(a.last_text,["--","-","++","+"]),h(e.text,["+","-"])&&h(a.last_text,["--","++"])&&(d=
!0)),(a.mode!==m.BlockStatement||a.inline_frame)&&a.mode!==m.Statement||"{"!==a.last_text&&";"!==a.last_text||q()):l&&(d=b=!1);k.space_before_token=k.space_before_token||b;t();k.space_before_token=d}},TK_COMMA:function(){t();k.space_before_token=!0;a.declaration_statement?(G(a.parent.mode)&&(a.declaration_assignment=!1),a.declaration_assignment?(a.declaration_assignment=!1,q(!1,!0)):g.comma_first&&v()):a.mode===m.ObjectLiteral||a.mode===m.Statement&&a.parent.mode===m.ObjectLiteral?(a.mode===m.Statement&&
z(),a.inline_frame||q()):g.comma_first&&v()},TK_BLOCK_COMMENT:function(){if(k.raw)k.add_raw_token(e),e.directives&&"end"===e.directives.preserve&&(k.raw=g.test_output_raw);else if(e.directives)q(!1,!0),t(),"start"===e.directives.preserve&&(k.raw=!0),q(!1,!0);else if(x.newline.test(e.text)||e.wanted_newline){for(var a=e.text,a=a.replace(x.allLineBreaks,"\n"),b=[],c=a.indexOf("\n");-1!==c;)b.push(a.substring(0,c)),a=a.substring(c+1),c=a.indexOf("\n");a.length&&b.push(a);var d=!1,f=!1,c=e.whitespace_before,
a=c.length;q(!1,!0);if(1<b.length){a:{d=b.slice(1);for(f=0;f<d.length;f++)if("*"!==d[f].replace(/^\s+|\s+$/g,"").charAt(0)){d=!1;break a}d=!0}a:{for(var f=b.slice(1),h=0,l=f.length,m;h<l;h++)if((m=f[h])&&0!==m.indexOf(c)){f=!1;break a}f=!0}}t(b[0]);for(c=1;c<b.length;c++)q(!1,!0),d?t(" "+b[c].replace(/^\s+/g,"")):f&&b[c].length>a?t(b[c].substring(a)):k.add_token(b[c]);q(!1,!0)}else k.space_before_token=!0,t(),k.space_before_token=!0},TK_COMMENT:function(){e.wanted_newline?q(!1,!0):k.trim(!0);k.space_before_token=
!0;t();q(!1,!0)},TK_DOT:function(){D();"TK_RESERVED"===f&&H(a.last_text)?k.space_before_token=!0:v(")"===a.last_text&&g.break_chained_methods);t()},TK_UNKNOWN:function(){t();"\n"===e.text[e.text.length-1]&&q()},TK_EOF:function(){for(;a.mode===m.Statement;)z()}};l=l?l:{};g={};void 0!==l.braces_on_own_line&&(g.brace_style=l.braces_on_own_line?"expand":"collapse");g.brace_style=l.brace_style?l.brace_style:g.brace_style?g.brace_style:"collapse";"expand-strict"===g.brace_style&&(g.brace_style="expand");
g.indent_size=l.indent_size?parseInt(l.indent_size,10):4;g.indent_char=l.indent_char?l.indent_char:" ";g.eol=l.eol?l.eol:"auto";g.preserve_newlines=void 0===l.preserve_newlines?!0:l.preserve_newlines;g.break_chained_methods=void 0===l.break_chained_methods?!1:l.break_chained_methods;g.max_preserve_newlines=void 0===l.max_preserve_newlines?0:parseInt(l.max_preserve_newlines,10);g.space_in_paren=void 0===l.space_in_paren?!1:l.space_in_paren;g.space_in_empty_paren=void 0===l.space_in_empty_paren?!1:
l.space_in_empty_paren;g.jslint_happy=void 0===l.jslint_happy?!1:l.jslint_happy;g.space_after_anon_function=void 0===l.space_after_anon_function?!1:l.space_after_anon_function;g.keep_array_indentation=void 0===l.keep_array_indentation?!1:l.keep_array_indentation;g.space_before_conditional=void 0===l.space_before_conditional?!0:l.space_before_conditional;g.unescape_strings=void 0===l.unescape_strings?!1:l.unescape_strings;g.wrap_line_length=void 0===l.wrap_line_length?0:parseInt(l.wrap_line_length,
10);g.e4x=void 0===l.e4x?!1:l.e4x;g.end_with_newline=void 0===l.end_with_newline?!1:l.end_with_newline;g.comma_first=void 0===l.comma_first?!1:l.comma_first;g.operator_position=T(l.operator_position);g.test_output_raw=void 0===l.test_output_raw?!1:l.test_output_raw;g.jslint_happy&&(g.space_after_anon_function=!0);l.indent_with_tabs&&(g.indent_char="\t",g.indent_size=1);"auto"===g.eol&&(g.eol="\n",b&&x.lineBreak.test(b||"")&&(g.eol=b.match(x.lineBreak)[0]));g.eol=g.eol.replace(/\\r/,"\r").replace(/\\n/,
"\n");for(u="";0<g.indent_size;)u+=g.indent_char,--g.indent_size;var E=0;if(b&&b.length){for(;" "===b.charAt(E)||"\t"===b.charAt(E);)M+=b.charAt(E),E+=1;b=b.substring(E)}f="TK_START_BLOCK";c="";k=new V(u,M);k.raw=g.test_output_raw;p=[];B(m.BlockStatement);this.beautify=function(){function d(){return e=C()}var e,h;w=new W(b,g,u);L=w.tokenize();for(F=0;d();){for(h=0;h<e.comments_before.length;h++)r(e.comments_before[h]);r(e);c=a.last_text;f=e.type;a.last_text=e.text;F+=1}h=k.get_code();g.end_with_newline&&
(h+="\n");"\n"!==g.eol&&(h=h.replace(/[\n]/g,g.eol));return h};var O=["break","contiue","return","throw"]}(O,S)).beautify()};"function"===typeof define&&define.amd?define([],function(){return{js_beautify:js_beautify}}):"undefined"!==typeof exports?exports.js_beautify=js_beautify:"undefined"!==typeof window?window.js_beautify=js_beautify:"undefined"!==typeof global&&(global.js_beautify=js_beautify)})();














/*jshint curly:true, eqeqeq:true, laxbreak:true, noempty:false */
/*

  The MIT License (MIT)

  Copyright (c) 2007-2013 Einar Lielmanis and contributors.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation files
  (the "Software"), to deal in the Software without restriction,
  including without limitation the rights to use, copy, modify, merge,
  publish, distribute, sublicense, and/or sell copies of the Software,
  and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.


 CSS Beautifier
---------------

    Written by Harutyun Amirjanyan, (amirjanyan@gmail.com)

    Based on code initially developed by: Einar Lielmanis, <einar@jsbeautifier.org>
        http://jsbeautifier.org/

    Usage:
        css_beautify(source_text);
        css_beautify(source_text, options);

    The options are (default in brackets):
        indent_size (4)                         — indentation size,
        indent_char (space)                     — character to indent with,
        selector_separator_newline (true)       - separate selectors with newline or
                                                  not (e.g. "a,\nbr" or "a, br")
        end_with_newline (false)                - end with a newline
        newline_between_rules (true)            - add a new line after every css rule
        space_around_selector_separator (false) - ensure space around selector separators:
                                                  '>', '+', '~' (e.g. "a>b" -> "a > b")
    e.g

    css_beautify(css_source_text, {
      'indent_size': 1,
      'indent_char': '\t',
      'selector_separator': ' ',
      'end_with_newline': false,
      'newline_between_rules': true,
      'space_around_selector_separator': true
    });
*/

// http://www.w3.org/TR/CSS21/syndata.html#tokenization
// http://www.w3.org/TR/css3-syntax/

(function(){window.css_beautify=function(f,d){function g(){return(a=f.charAt(++e))||""}function l(a){var b=e;a&&m();a=f.charAt(e+1)||"";e=b-1;g();return a}function q(b){for(var c=e;g();)if("\\"===a)g();else if(-1!==b.indexOf(a))break;else if("\n"===a)break;return f.substring(c,e+1)}function F(a){var b=e;a=q(a);e=b-1;g();return a}function m(){for(var b="";v.test(l());)g(),b+=a;return b}function G(){var b="";for(a&&v.test(a)&&(b=a);v.test(g());)b+=a;return b}function B(b){var c=e;b="/"===l();for(g();g();)if(!b&&
"*"===a&&"/"===l()){g();break}else if(b&&"\n"===a)return f.substring(c,e);return f.substring(c,e)+a}function C(a){return f.substring(e-a.length,e).toLowerCase()===a}function H(){for(var a=0,b=e+1;b<f.length;b++){var c=f.charAt(b);if("{"===c)return!0;if("("===c)a+=1;else if(")"===c){if(0===a)break;--a}else if(";"===c||"}"===c)break}return!1}d=d||{};f=f||"";f=f.replace(/\r\n|[\r\u2028\u2029]/g,"\n");var h=d.indent_size||4,w=d.indent_char||" ",I=void 0===d.selector_separator_newline?!0:d.selector_separator_newline,
J=void 0===d.end_with_newline?!1:d.end_with_newline,D=void 0===d.newline_between_rules?!0:d.newline_between_rules,K=void 0===d.space_around_selector_separator?!1:d.space_around_selector_separator,x=d.eol?d.eol:"\n";"string"===typeof h&&(h=parseInt(h,10));d.indent_with_tabs&&(w="\t",h=1);for(var x=x.replace(/\\r/,"\r").replace(/\\n/,"\n"),v=/^\s+$/,e=-1,a,y=0,n=f.match(/^[\t ]*/)[0],w=Array(h+1).join(w),p=0,r=0,b={"{":function(a){b.singleSpace();c.push(a);b.newLine()},"}":function(a){b.newLine();c.push(a);
b.newLine()},_lastCharWhitespace:function(){return v.test(c[c.length-1])},newLine:function(a){c.length&&(a||"\n"===c[c.length-1]||b.trim(),c.push("\n"),n&&c.push(n))},singleSpace:function(){c.length&&!b._lastCharWhitespace()&&c.push(" ")},preserveSingleSpace:function(){L&&b.singleSpace()},trim:function(){for(;b._lastCharWhitespace();)c.pop()}},c=[],z=!1,t=!1,A=!1,E="",u="";;){var k=G(),L=""!==k,k=-1!==k.indexOf("\n"),u=E;if(E=a)"/"===a&&"*"===l()?(u=0===p,(k||u)&&b.newLine(),c.push(B()),b.newLine(),
u&&b.newLine(!0)):"/"===a&&"/"===l()?(k||"{"===u||b.trim(),b.singleSpace(),c.push(B()),b.newLine()):"@"===a?(b.preserveSingleSpace(),"{"===l()?c.push(q("}")):(c.push(a),k=F(": ,;{}()[]/='\""),k.match(/[ :]$/)&&(g(),k=q(": ").replace(/\s$/,""),c.push(k),b.singleSpace()),k=k.replace(/\s$/,""),k in css_beautify.NESTED_AT_RULE&&(r+=1,k in css_beautify.CONDITIONAL_GROUP_RULE&&(A=!0)))):"#"===a&&"{"===l()?(b.preserveSingleSpace(),c.push(q("}"))):"{"===a?"}"===l(!0)?(m(),g(),b.singleSpace(),c.push("{}"),
b.newLine(),D&&0===p&&b.newLine(!0)):(p++,n+=w,b["{"](a),A?(A=!1,z=p>r):z=p>=r):"}"===a?(p--,n=n.slice(0,-h),b["}"](a),t=z=!1,r&&r--,D&&0===p&&b.newLine(!0)):":"===a?(m(),!z&&!A||C("&")||H()?":"===l()?(g(),c.push("::")):c.push(":"):(t=!0,c.push(":"),b.singleSpace())):'"'===a||"'"===a?(b.preserveSingleSpace(),c.push(q(a))):";"===a?(t=!1,c.push(a),b.newLine()):"("===a?C("url")?(c.push(a),m(),g()&&(")"!==a&&'"'!==a&&"'"!==a?c.push(q(")")):e--)):(y++,b.preserveSingleSpace(),c.push(a),m()):")"===a?(c.push(a),
y--):","===a?(c.push(a),m(),I&&!t&&1>y?b.newLine():b.singleSpace()):">"===a||"+"===a||"~"===a?K&&!t&&1>y?(b.singleSpace(),c.push(a),b.singleSpace()):c.push(a):("]"!==a&&("["===a?b.preserveSingleSpace():"="===a?(m(),a="="):b.preserveSingleSpace()),c.push(a));else break}h="";n&&(h+=n);h+=c.join("").replace(/[\r\n\t ]+$/,"");J&&(h+="\n");"\n"!==x&&(h=h.replace(/[\n]/g,x));return h};css_beautify.NESTED_AT_RULE={"@page":!0,"@font-face":!0,"@keyframes":!0,"@media":!0,"@supports":!0,"@document":!0};css_beautify.CONDITIONAL_GROUP_RULE=
{"@media":!0,"@supports":!0,"@document":!0};"function"===typeof define&&define.amd?define([],function(){return{css_beautify:css_beautify}}):"undefined"!==typeof exports?exports.css_beautify=css_beautify:"undefined"!==typeof window?window.css_beautify=css_beautify:"undefined"!==typeof global&&(global.css_beautify=css_beautify)})();















/*jshint curly:true, eqeqeq:true, laxbreak:true, noempty:false */
/*

  The MIT License (MIT)

  Copyright (c) 2007-2013 Einar Lielmanis and contributors.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation files
  (the "Software"), to deal in the Software without restriction,
  including without limitation the rights to use, copy, modify, merge,
  publish, distribute, sublicense, and/or sell copies of the Software,
  and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.


 Style HTML
---------------

  Written by Nochum Sossonko, (nsossonko@hotmail.com)

  Based on code initially developed by: Einar Lielmanis, <einar@jsbeautifier.org>
    http://jsbeautifier.org/

  Usage:
    style_html(html_source);

    style_html(html_source, options);

  The options are:
    indent_inner_html (default false)  — indent <head> and <body> sections,
    indent_size (default 4)          — indentation size,
    indent_char (default space)      — character to indent with,
    wrap_line_length (default 250)            -  maximum amount of characters per line (0 = disable)
    brace_style (default "collapse") - "collapse" | "expand" | "end-expand" | "none"
            put braces on the same line as control statements (default), or put braces on own line (Allman / ANSI style), or just put end braces on own line, or attempt to keep them where they are.
    unformatted (defaults to inline tags) - list of tags, that shouldn't be reformatted
    indent_scripts (default normal)  - "keep"|"separate"|"normal"
    preserve_newlines (default true) - whether existing line breaks before elements should be preserved
                                        Only works before elements, not inside tags or for text.
    max_preserve_newlines (default unlimited) - maximum number of line breaks to be preserved in one chunk
    indent_handlebars (default false) - format and indent {{#foo}} and {{/foo}}
    end_with_newline (false)          - end with a newline
    extra_liners (default [head,body,/html]) -List of tags that should have an extra newline before them.

    e.g.

    style_html(html_source, {
      'indent_inner_html': false,
      'indent_size': 2,
      'indent_char': ' ',
      'wrap_line_length': 78,
      'brace_style': 'expand',
      'preserve_newlines': true,
      'max_preserve_newlines': 5,
      'indent_handlebars': false,
      'extra_liners': ['/html']
    });
*/

(function(){window.style_html=function(e,b,p,w){var a,x,y,z,f,q,g,r,t,A,B,h,v,C,D,E,n;b=b||{};void 0!==b.wrap_line_length&&0!==parseInt(b.wrap_line_length,10)||void 0===b.max_char||0===parseInt(b.max_char,10)||(b.wrap_line_length=b.max_char);x=void 0===b.indent_inner_html?!1:b.indent_inner_html;y=void 0===b.indent_body_inner_html?!0:b.indent_body_inner_html;z=void 0===b.indent_head_inner_html?!0:b.indent_head_inner_html;f=void 0===b.indent_size?4:parseInt(b.indent_size,10);q=void 0===b.indent_char?
" ":b.indent_char;r=void 0===b.brace_style?"collapse":b.brace_style;g=0===parseInt(b.wrap_line_length,10)?32786:parseInt(b.wrap_line_length||250,10);t=b.unformatted||"a abbr area audio b bdi bdo br button canvas cite code data datalist del dfn em embed i iframe img input ins kbd keygen label map mark math meter noscript object output progress q ruby s samp select small span strong sub sup svg template textarea time u var video wbr text acronym address big dt ins small strike tt pre h1 h2 h3 h4 h5 h6".split(" ");
B=(A=void 0===b.preserve_newlines?!0:b.preserve_newlines)?isNaN(parseInt(b.max_preserve_newlines,10))?32786:parseInt(b.max_preserve_newlines,10):0;h=void 0===b.indent_handlebars?!1:b.indent_handlebars;v=void 0===b.wrap_attributes?"auto":b.wrap_attributes;C=isNaN(parseInt(b.wrap_attributes_indent_size,10))?f:parseInt(b.wrap_attributes_indent_size,10);D=void 0===b.end_with_newline?!1:b.end_with_newline;E="object"===typeof b.extra_liners&&b.extra_liners?b.extra_liners.concat():"string"===typeof b.extra_liners?
b.extra_liners.split(","):["head","body","/html"];n=b.eol?b.eol:"\n";b.indent_with_tabs&&(q="\t",f=1);n=n.replace(/\\r/,"\r").replace(/\\n/,"\n");a=new function(){function a(d){var c="";return{add:function(a){a=c+a.toLowerCase();c=a.length<=d.length?a:a.substr(a.length-d.length,d.length)},doesNotMatch:function(){return-1===c.indexOf(d)}}}this.pos=0;this.token="";this.current_mode="CONTENT";this.tags={parent:"parent1",parentcount:1,parent1:""};this.token_text=this.last_token=this.last_text=this.token_type=
this.tag_type="";this.newlines=0;this.indent_content=x;this.indent_body_inner_html=y;this.indent_head_inner_html=z;this.Utils={whitespace:["\n","\r","\t"," "],single_token:"area base br col embed hr img input keygen link menuitem meta param source track wbr !doctype ?xml ?php basefont isindex".split(" "),extra_liners:E,in_array:function(d,c){for(var a=0;a<c.length;a++)if(d===c[a])return!0;return!1}};this.is_whitespace=function(d){for(var c=0;c<d.length;c++)if(!this.Utils.in_array(d.charAt(c),this.Utils.whitespace))return!1;
return!0};this.traverse_whitespace=function(){var d;d=this.input.charAt(this.pos);if(this.Utils.in_array(d,this.Utils.whitespace)){for(this.newlines=0;this.Utils.in_array(d,this.Utils.whitespace);)A&&"\n"===d&&this.newlines<=B&&(this.newlines+=1),this.pos++,d=this.input.charAt(this.pos);return!0}return!1};this.space_or_wrap=function(d){if(this.line_char_count>=this.wrap_line_length)return this.print_newline(!1,d),this.print_indentation(d),!0;this.line_char_count++;d.push(" ");return!1};this.get_content=
function(){for(var d,c=[];"<"!==this.input.charAt(this.pos);){if(this.pos>=this.input.length)return c.length?c.join(""):["","TK_EOF"];if(this.traverse_whitespace())this.space_or_wrap(c);else{if(h)if(d=this.input.substr(this.pos,3),"{{#"===d||"{{/"===d)break;else{if("{{!"===d)return[this.get_tag(),"TK_TAG_HANDLEBARS_COMMENT"];if("{{"===this.input.substr(this.pos,2)&&"{{else}}"===this.get_tag(!0))break}d=this.input.charAt(this.pos);this.pos++;this.line_char_count++;c.push(d)}}return c.length?c.join(""):
""};this.get_contents_to=function(d){if(this.pos===this.input.length)return["","TK_EOF"];var c="";d=new RegExp("</"+d+"\\s*>","igm");d.lastIndex=this.pos;d=(d=d.exec(this.input))?d.index:this.input.length;this.pos<d&&(c=this.input.substring(this.pos,d),this.pos=d);return c};this.record_tag=function(d){this.tags[d+"count"]?this.tags[d+"count"]++:this.tags[d+"count"]=1;this.tags[d+this.tags[d+"count"]]=this.indent_level;this.tags[d+this.tags[d+"count"]+"parent"]=this.tags.parent;this.tags.parent=d+
this.tags[d+"count"]};this.retrieve_tag=function(d){if(this.tags[d+"count"]){for(var c=this.tags.parent;c&&d+this.tags[d+"count"]!==c;)c=this.tags[c+"parent"];c&&(this.indent_level=this.tags[d+this.tags[d+"count"]],this.tags.parent=this.tags[c+"parent"]);delete this.tags[d+this.tags[d+"count"]+"parent"];delete this.tags[d+this.tags[d+"count"]];1===this.tags[d+"count"]?delete this.tags[d+"count"]:this.tags[d+"count"]--}};this.indent_to_tag=function(d){if(this.tags[d+"count"]){for(var c=this.tags.parent;c&&
d+this.tags[d+"count"]!==c;)c=this.tags[c+"parent"];c&&(this.indent_level=this.tags[d+this.tags[d+"count"]])}};this.get_tag=function(d){var c,a=[],b=!1,e=!0,l,m,f=this.pos,g=this.line_char_count;d=void 0!==d?d:!1;do{if(this.pos>=this.input.length)return d&&(this.pos=f,this.line_char_count=g),a.length?a.join(""):["","TK_EOF"];c=this.input.charAt(this.pos);this.pos++;if(this.Utils.in_array(c,this.Utils.whitespace))b=!0;else{if("'"===c||'"'===c)c+=this.get_unformatted(c),b=!0;"="===c&&(b=!1);if(a.length&&
"="!==a[a.length-1]&&">"!==c&&b){var k=this.space_or_wrap(a)&&"/"!==c&&"force"!==v,b=!1;e||"force"!==v||"/"===c||(this.print_newline(!1,a),this.print_indentation(a),k=!0);if(k)for(k=0;k<C;k++)a.push(q);for(k=0;k<a.length;k++)if(" "===a[k]){e=!1;break}}h&&"<"===m&&"{{"===c+this.input.charAt(this.pos)&&(c+=this.get_unformatted("}}"),a.length&&" "!==a[a.length-1]&&"<"!==a[a.length-1]&&(c=" "+c),b=!0);"<"!==c||m||(l=this.pos-1,m="<");h&&!m&&2<=a.length&&"{"===a[a.length-1]&&"{"===a[a.length-2]&&(l="#"===
c||"/"===c||"!"===c?this.pos-3:this.pos-2,m="{");this.line_char_count++;a.push(c);if(a[1]&&("!"===a[1]||"?"===a[1]||"%"===a[1])){a=[this.get_comment(l)];break}if(h&&a[1]&&"{"===a[1]&&a[2]&&"!"===a[2]){a=[this.get_comment(l)];break}if(h&&"{"===m&&2<a.length&&"}"===a[a.length-2]&&"}"===a[a.length-1])break}}while(">"!==c);c=a.join("");b=-1!==c.indexOf(" ")?c.indexOf(" "):"{"===c.charAt(0)?c.indexOf("}"):c.indexOf(">");e="<"!==c.charAt(0)&&h?"#"===c.charAt(2)?3:2:1;b=c.substring(e,b).toLowerCase();"/"===
c.charAt(c.length-2)||this.Utils.in_array(b,this.Utils.single_token)?d||(this.tag_type="SINGLE"):h&&"{"===c.charAt(0)&&"else"===b?d||(this.indent_to_tag("if"),this.tag_type="HANDLEBARS_ELSE",this.indent_content=!0,this.traverse_whitespace()):this.is_unformatted(b,t)?(c=this.get_unformatted("</"+b+">",c),a.push(c),this.tag_type="SINGLE"):"script"===b&&(-1===c.search("type")||-1<c.search("type")&&-1<c.search(/\b(text|application)\/(x-)?(javascript|ecmascript|jscript|livescript|(ld\+)?json)/))?d||(this.record_tag(b),
this.tag_type="SCRIPT"):"style"===b&&(-1===c.search("type")||-1<c.search("type")&&-1<c.search("text/css"))?d||(this.record_tag(b),this.tag_type="STYLE"):"!"===b.charAt(0)?d||(this.tag_type="SINGLE",this.traverse_whitespace()):d||("/"===b.charAt(0)?(this.retrieve_tag(b.substring(1)),this.tag_type="END"):(this.record_tag(b),"html"!==b.toLowerCase()&&(this.indent_content=!0),this.tag_type="START"),this.traverse_whitespace()&&this.space_or_wrap(a),this.Utils.in_array(b,this.Utils.extra_liners)&&(this.print_newline(!1,
this.output),this.output.length&&"\n"!==this.output[this.output.length-2]&&this.print_newline(!0,this.output)));d&&(this.pos=f,this.line_char_count=g);return a.join("")};this.get_comment=function(a){var c="",b=">",e=!1;this.pos=a;a=this.input.charAt(this.pos);for(this.pos++;this.pos<=this.input.length;){c+=a;if(c.charAt(c.length-1)===b.charAt(b.length-1)&&-1!==c.indexOf(b))break;!e&&10>c.length&&(0===c.indexOf("<![if")?(b="<![endif]>",e=!0):0===c.indexOf("<![cdata[")?(b="]]\x3e",e=!0):0===c.indexOf("<![")?
(b="]>",e=!0):0===c.indexOf("\x3c!--")?(b="--\x3e",e=!0):0===c.indexOf("{{!")?(b="}}",e=!0):0===c.indexOf("<?")?(b="?>",e=!0):0===c.indexOf("<%")&&(b="%>",e=!0));a=this.input.charAt(this.pos);this.pos++}return c};this.get_unformatted=function(d,c){if(c&&-1!==c.toLowerCase().indexOf(d))return"";var b,e="",f=!0,l=a(d);do{if(this.pos>=this.input.length)break;b=this.input.charAt(this.pos);this.pos++;if(this.Utils.in_array(b,this.Utils.whitespace)){if(!f){this.line_char_count--;continue}if("\n"===b||"\r"===
b){e+="\n";this.line_char_count=0;continue}}e+=b;l.add(b);this.line_char_count++;f=!0;h&&"{"===b&&e.length&&"{"===e.charAt(e.length-2)&&(e+=this.get_unformatted("}}"))}while(l.doesNotMatch());return e};this.get_token=function(){var a;if("TK_TAG_SCRIPT"===this.last_token||"TK_TAG_STYLE"===this.last_token){var b=this.last_token.substr(7);a=this.get_contents_to(b);return"string"!==typeof a?a:[a,"TK_"+b]}if("CONTENT"===this.current_mode)return a=this.get_content(),"string"!==typeof a?a:[a,"TK_CONTENT"];
if("TAG"===this.current_mode)return a=this.get_tag(),"string"!==typeof a?a:[a,"TK_TAG_"+this.tag_type]};this.get_full_indent=function(a){a=this.indent_level+a||0;return 1>a?"":Array(a+1).join(this.indent_string)};this.is_unformatted=function(a,b){if(!this.Utils.in_array(a,b))return!1;if("a"!==a.toLowerCase()||!this.Utils.in_array("a",b))return!0;var e=(this.get_tag(!0)||"").match(/^\s*<\s*\/?([a-z]*)\s*[^>]*>\s*$/);return!e||this.Utils.in_array(e,b)?!0:!1};this.printer=function(a,b,e,f,g){this.input=
a||"";this.input=this.input.replace(/\r\n|[\r\u2028\u2029]/g,"\n");this.output=[];this.indent_character=b;this.indent_string="";this.indent_size=e;this.brace_style=g;this.indent_level=0;this.wrap_line_length=f;for(a=this.line_char_count=0;a<this.indent_size;a++)this.indent_string+=this.indent_character;this.print_newline=function(a,b){this.line_char_count=0;b&&b.length&&(a||"\n"!==b[b.length-1])&&("\n"!==b[b.length-1]&&(b[b.length-1]=b[b.length-1].replace(/\s+$/g,"")),b.push("\n"))};this.print_indentation=
function(a){for(var b=0;b<this.indent_level;b++)a.push(this.indent_string),this.line_char_count+=this.indent_string.length};this.print_token=function(a){if(!this.is_whitespace(a)||this.output.length)(a||""!==a)&&this.output.length&&"\n"===this.output[this.output.length-1]&&(this.print_indentation(this.output),a=a.replace(/^\s+/g,"")),this.print_token_raw(a)};this.print_token_raw=function(a){0<this.newlines&&(a=a.replace(/\s+$/g,""));a&&""!==a&&(1<a.length&&"\n"===a.charAt(a.length-1)?(this.output.push(a.slice(0,
-1)),this.print_newline(!1,this.output)):this.output.push(a));for(a=0;a<this.newlines;a++)this.print_newline(0<a,this.output);this.newlines=0};this.indent=function(){this.indent_level++};this.unindent=function(){0<this.indent_level&&this.indent_level--}};return this};for(a.printer(e,q,f,g,r);;){e=a.get_token();a.token_text=e[0];a.token_type=e[1];if("TK_EOF"===a.token_type)break;switch(a.token_type){case "TK_TAG_START":a.print_newline(!1,a.output);a.print_token(a.token_text);a.indent_content&&(!a.indent_body_inner_html&&
a.token_text.match(/<body(?:.*)>/)||!a.indent_head_inner_html&&a.token_text.match(/<head(?:.*)>/)||a.indent(),a.indent_content=!1);a.current_mode="CONTENT";break;case "TK_TAG_STYLE":case "TK_TAG_SCRIPT":a.print_newline(!1,a.output);a.print_token(a.token_text);a.current_mode="CONTENT";break;case "TK_TAG_END":"TK_CONTENT"===a.last_token&&""===a.last_text&&(e=(a.token_text.match(/\w+/)||[])[0],f=null,a.output.length&&(f=a.output[a.output.length-1].match(/(?:<|{{#)\s*(\w+)/)),(null===f||f[1]!==e&&!a.Utils.in_array(f[1],
t))&&a.print_newline(!1,a.output));a.print_token(a.token_text);a.current_mode="CONTENT";break;case "TK_TAG_SINGLE":(e=a.token_text.match(/^\s*<([a-z-]+)/i))&&a.Utils.in_array(e[1],t)||a.print_newline(!1,a.output);a.print_token(a.token_text);a.current_mode="CONTENT";break;case "TK_TAG_HANDLEBARS_ELSE":e=!1;for(f=a.output.length-1;0<=f&&"\n"!==a.output[f];f--)if(a.output[f].match(/{{#if/)){e=!0;break}e||a.print_newline(!1,a.output);a.print_token(a.token_text);a.indent_content&&(a.indent(),a.indent_content=
!1);a.current_mode="CONTENT";break;case "TK_TAG_HANDLEBARS_COMMENT":a.print_token(a.token_text);a.current_mode="TAG";break;case "TK_CONTENT":a.print_token(a.token_text);a.current_mode="TAG";break;case "TK_STYLE":case "TK_SCRIPT":if(""!==a.token_text){a.print_newline(!1,a.output);e=a.token_text;var u;g=1;"TK_SCRIPT"===a.token_type?u="function"===typeof p&&p:"TK_STYLE"===a.token_type&&(u="function"===typeof w&&w);"keep"===b.indent_scripts?g=0:"separate"===b.indent_scripts&&(g=-a.indent_level);f=a.get_full_indent(g);
u?(g=function(){this.eol="\n"},g.prototype=b,g=new g,e=u(e.replace(/^\s*/,f),g)):(r=e.match(/^\s*/)[0].match(/[^\n\r]*$/)[0].split(a.indent_string).length-1,g=a.get_full_indent(g-r),e=e.replace(/^\s*/,f).replace(/\r\n|\r|\n/g,"\n"+g).replace(/\s+$/,""));e&&(a.print_token_raw(e),a.print_newline(!0,a.output))}a.current_mode="TAG";break;default:""!==a.token_text&&a.print_token(a.token_text)}a.last_token=a.token_type;a.last_text=a.token_text}b=a.output.join("").replace(/[\r\n\t ]+$/,"");D&&(b+="\n");
"\n"!==n&&(b=b.replace(/[\n]/g,n));return b};if("function"===typeof define&&define.amd)define(["require","./beautify","./beautify-css"],function(e){var b=e("./beautify"),p=e("./beautify-css");return{html_beautify:function(e,a){return style_html(e,a,b.js_beautify,p.css_beautify)}}});else if("undefined"!==typeof exports){var F=require("./beautify.js"),G=require("./beautify-css.js");exports.html_beautify=function(e,b){return style_html(e,b,F.js_beautify,G.css_beautify)}}else"undefined"!==typeof window?
window.html_beautify=function(e,b){return style_html(e,b,window.js_beautify,window.css_beautify)}:"undefined"!==typeof global&&(global.html_beautify=function(e,b){return style_html(e,b,global.js_beautify,global.css_beautify)})})();